Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(245)

Unified Diff: src/gpu/GrRecordReplaceDraw.h

Issue 608823002: Update RecordReplaceDrawTest to generate and pass pictures (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Reordered #include files Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « include/core/SkPicture.h ('k') | src/gpu/GrRecordReplaceDraw.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/GrRecordReplaceDraw.h
diff --git a/src/gpu/GrRecordReplaceDraw.h b/src/gpu/GrRecordReplaceDraw.h
index 3ba43dc2f04db764ca9a3122fada0f8e14f87b18..4900e0d2417ec7d34d3faf58866814b2a1929b27 100644
--- a/src/gpu/GrRecordReplaceDraw.h
+++ b/src/gpu/GrRecordReplaceDraw.h
@@ -16,7 +16,9 @@ class SkBBoxHierarchy;
class SkBitmap;
class SkCanvas;
class SkImage;
+class SkMatrix;
class SkPaint;
+class SkPicture;
class SkRecord;
// GrReplacements collects op ranges that can be replaced with
@@ -58,12 +60,12 @@ private:
#endif
};
// Draw an SkRecord into an SkCanvas replacing saveLayer/restore blocks with
// drawBitmap calls. A convenience wrapper around SkRecords::Draw.
-void GrRecordReplaceDraw(const SkRecord&,
+void GrRecordReplaceDraw(const SkPicture*,
SkCanvas*,
- const SkBBoxHierarchy*,
const GrReplacements*,
+ const SkMatrix&,
SkDrawPictureCallback*);
#endif // GrRecordReplaceDraw_DEFINED
« no previous file with comments | « include/core/SkPicture.h ('k') | src/gpu/GrRecordReplaceDraw.cpp » ('j') | no next file with comments »
@@ -58,12 +60,12 @@ private:
#endif
};
-// Draw an SkRecord into an SkCanvas replacing saveLayer/restore blocks with
+// Draw an SkPicture into an SkCanvas replacing saveLayer/restore blocks with
// drawBitmap calls. A convenience wrapper around SkRecords::Draw.

Powered by Google App Engine
This is Rietveld 408576698